@@ -69,7 +69,11 @@ class OMFITchease(SortedDict, OMFITascii):
             n3 = 2
         elif len(tmp) == 3:
             self.version = 'mars'
-            n1, n2, n3, = list(map(int, tmp))
+            (
+                n1,
+                n2,
+                n3,
+            ) = list(map(int, tmp))
         else:
             raise OMFITexception('%s is not a valid OMFITchease file' % self.filename)
 
@@ -219,6 +223,24 @@ class OMFITchease(SortedDict, OMFITascii):
 
         return RS, ZS
 
+    def addLimiter(self, R, Z):
+        """
+        Insertion of a wall defined by coordinates (R,Z)
+
+        :R = radial coordinate
+
+        :Z = vertical coordinate
+
+        Note: both must be normalized, and ndarray type
+        """
+        if len(self['BOUNDARY']) == 0:
+            raise ("Error. No PLASMA found")
+        else:
+            d = len(self['BOUNDARY']) - 1
+            self['BOUNDARY']['LIMITER_' + str(d)] = {}
+            self['BOUNDARY']['LIMITER_' + str(d)]['R'] = R
+            self['BOUNDARY']['LIMITER_' + str(d)]['Z'] = Z
+
     def modifyBoundary(self):
         """
         Interactively modify plasma boundary
