@@ -255,6 +255,8 @@ __all__ = [
     'importDataset',
     'OMFITncDataset',
     'OMFITncDynamicDataset',
+    'pandas_read_json',
+    'DataFrame',
 ]
 if not np.any([('sphinx' in k and not 'sphinxcontrib' in k) for k in sys.modules]):
     __all__.extend(['DataArray', 'Dataset'])
@@ -694,7 +696,7 @@ class OMFITncDynamicDataset(OMFITncDataset):
             self._dynamic_keys[:] = tmp
 
 
-######################################################### Monkey-patch xarray plotting
+############################################ Monkey-patch xarray plotting
 
 from xarray.plot.plot import _PlotMethods
 
@@ -790,6 +792,11 @@ def _uplot(data, ax=None, **kw):
 _uplot.__doc__ = DataArray.plot.__doc__
 DataArray.plot = _uplot
 
+############################################
+
+from pandas import read_json as pandas_read_json
+from pandas import DataFrame
+
 ############################################
 if '__main__' == __name__:
     test_classes_main_header()
