@@ -94,10 +94,9 @@ class OMFITnimrod(SortedDict, OMFITobject):
         'n_{neut} [m^{-3}]',  # 58
         'Im n_{neut} [m^{-3}]',  # 59
         'n_{imp neut} [m^{-3}]',  # 60
-        'n_{imp +1} [m^{-3}]',  # 61
-        'n_{imp +2} [m^{-3}]',
-    ]  # 62
-
+    ]
+    for iz in range(1, 19):
+        contour_labels.append('n_{imp +' + str(iz) + '} [m^{-3}]')
     discharge_labels = [
         'istep',
         'time',
@@ -439,10 +438,10 @@ class OMFITnimrod(SortedDict, OMFITobject):
                 if 'Im ' + label in self.contour_labels:
                     kI = self.contour_labels.index('Im ' + label)
                     self[label] = self._merge_blocks(varr[:, :, :, :, k] + 1j * varr[:, :, :, :, kI])
-                elif ('{imp' in label) and (k + (nvar - 55) // 2 < nvar):
-                    kI = k + (nvar - 55) // 2
+                elif ('{imp' in label) and (k + (nvar - 59) // 2 < nvar):
+                    kI = k + (nvar - 59) // 2
                     self[label] = self._merge_blocks(varr[:, :, :, :, k] + 1j * varr[:, :, :, :, kI])
-                else:
+                elif k < 59:
                     self[label] = self._merge_blocks(varr[:, :, :, :, k])
 
     def _plot_contour(self, slice=0, phase=0, nlevels=21):
