@@ -37,6 +37,7 @@ _RDBserverDict = {
     'C-Mod': 'alcdb2',
     'EAST': 'east_database',
     'east': 'east_database',
+    'nstx': 'nstxrdb',
 }
 
 
@@ -95,10 +96,12 @@ def _read_rdb_password_from_file(server=None, filename=None):
     password = ''
     files = {
         'huez': ['.pgdb', '.pgpass'],
+        'pppl_postgres': ['.pgdb', '.pgpass'],
         'd3drdb': ['D3DRDB.sybase_login', 'd3drdb.sybase_login'],
         'd3dsqlsrvr': ['D3DRDB.sybase_login', 'd3drdb.sybase_login'],
         'd3sqlsrvr': ['D3SQLSRVR.sybase_login', 'd3sqlsrvr.sybase_login'],
         'east_database': ['east_database.sybase_login'],
+        'nstxrdb': ['nstxlogs.sybase_login'],
     }.get(translate_RDBserver(server), [''])
     files = [filename] if filename is not None else files
 
@@ -106,7 +109,7 @@ def _read_rdb_password_from_file(server=None, filename=None):
         return map(lambda x: x.strip(), ff.read().split(':')[-2:])
 
     def parse_login2(ff):
-        return map(lambda x: x.strip(), ff.readlines())
+        return map(lambda x: x.strip(), ff.readlines()[-2:])
 
     parsers = [parse_login1, parse_login2]
     printq('Searching for {} login info in files {}'.format(server, files))
@@ -136,7 +139,7 @@ def get_public_rdb_login(server):
     :return: (string, string)
     """
     default_user_pass = ('guest', 'guest_pwd')  # Applies to d3drdb, d3dsqlsrvr, d3sqlsrvr, east_database
-    return {'huez': ('d3dpub', 'd3dpub')}.get(translate_RDBserver(server), default_user_pass)
+    return {'huez': ('d3dpub', 'd3dpub'), 'pppl_postgres': ('nstxpub', 'nstxpub')}.get(translate_RDBserver(server), default_user_pass)
 
 
 def set_rdb_password(server, username=None, password=None, guest=False):
@@ -262,7 +265,7 @@ class OMFITrdb(SortedDict):
 
     @property
     def postgresql(self):
-        return self.db == 'd3d' or self.server == 'huez'
+        return self.db == 'd3d' or self.server == 'huez' or self.server == 'pppl_postgres'
 
     def _connect(self):
         """Connects to the database"""
@@ -803,8 +806,9 @@ If this file is not available to you contact the GA computer group: iris-support
     def _setup_connection(self, force_tunnel=False):
         # Get server/tunnel from OMFIT['MainSettings']['SERVER'] list
         server0 = translate_RDBserver(self.server, _RDBserverDict)
-        server = OMFIT['MainSettings']['SERVER'][server0]['RDB_server']
-        tunnel = OMFIT['MainSettings']['SERVER'][server0]['tunnel']
+        MS_server0 = OMFIT['MainSettings']['SERVER'][server0]
+        server = MS_server0['RDB_server']
+        tunnel = MS_server0.get('tunnel', '')
 
         # Try directly connecting to the RDB server
         if server not in OMFITaux['RDBserverReachable']:
@@ -831,9 +835,12 @@ If this file is not available to you contact the GA computer group: iris-support
             connection['PWD'] = password
             connection['SERVER'] = rdb_server[2]
             connection['PORT'] = rdb_server[3]
+            if 'instance' in MS_server0:
+                del connection['PORT']
+                connection['SERVER'] = f"{connection['SERVER']}\{MS_server0['instance']}"
             driver = 'tdsodbc'
-            if 'driver' in list(OMFIT['MainSettings']['SERVER'][server0].keys()):
-                connection['DRIVER'] = driver = OMFIT['MainSettings']['SERVER'][server0]['driver']
+            if 'driver' in MS_server0:
+                connection['DRIVER'] = driver = MS_server0['driver']
             if isinstance(driver, str) and driver and os.sep not in driver:
                 connection['DRIVER'] = find_library(driver)
             if not isinstance(connection['DRIVER'], str) or not connection['DRIVER']:
@@ -842,9 +849,9 @@ If this file is not available to you contact the GA computer group: iris-support
                 )
             if 'tdsodbc' in driver:
                 connection['TDS_Version'] = '8.0'
-            for k in list(OMFIT['MainSettings']['SERVER'][server0].keys()):
-                if k not in list(connection.keys()) + ['driver', 'server', 'tunnel', 'RDB_server']:
-                    connection[k] = OMFIT['MainSettings']['SERVER'][server0][k]
+            for k in MS_server0:
+                if k not in list(connection.keys()) + ['driver', 'server', 'tunnel', 'RDB_server', 'instance']:
+                    connection[k] = MS_server0[k]
         else:
             connection['user'] = username
             connection['password'] = password
