@@ -227,6 +227,8 @@ class setup_warnings(object):
             warnings.filterwarnings('ignore', category=UserWarning, message="Warning: converting a masked element to nan.")
             # psycopg2
             warnings.filterwarnings('ignore', message='The psycopg2 wheel package will be renamed from release 2.8*')
+            # pandas
+            warnings.filterwarnings('ignore', message="Pandas doesn't allow columns to be created via a new attribute name*")
 
         if level <= 1:
             # Divide by 0
