@@ -2,7 +2,6 @@ from omfit_classes.utils_base import *
 from omfit_classes.utils_base import _available_to_user_math, _available_to_user_util, _available_to_user_plot
 
 import numpy as np
-import pickle as pypickle
 import pickle
 import functools
 import ast
@@ -14,6 +13,7 @@ import difflib
 import re
 import pprint
 import warnings
+import traceback
 
 __all__ = [
     'hide_ptrn',
@@ -769,8 +769,8 @@ class SortedDict(dict):
         ):
             try:
                 if os.environ['USER'] == 'meneghini':
-                    printw('%s dynaloading because %s attribute was requested' % (self.__class__.__name__, attr))
-                    print_stack()
+                    print('%s dynaloading because %s attribute was requested' % (self.__class__.__name__, attr), file=sys.__stderr__)
+                    traceback.print_stack(file=sys.__stderr__)
                 self.__dict__['getattr_infiniteloop_block'] = True
                 dynaLoader(self)
                 return getattr(self, attr)
